# wwd


<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

`wwd`: `westworld` but available on PyPI

## Components

- `api`: Unified API for LM-related inference
- `nbs`: nbdev notebooks for main package
- `notes`: Research notes
- `papers`: Research papers
- `ra`: Research assistant tool
- `sh`: Shell scripts
- `vendor`: Git submodules
- `wwd`: Main package

## Goals

- Data pipelines
- Benchmarks
- Create intent based API for LM-related inference
- Create RAG+ research assistant tool
- Reimplement
  - Embedding
  - Reranking
  - Transformer (NanoGPT/Mistral/LLaMA)
  - Multi-modal transformer (LLaVA)
  - RNN (RWKV)
  - SSM (Mamba)
  - Spiking NN
  - Forward-forward
- Research additions
  - RAG over previous interactions
  - Fused backprop step at inference for transformers
- Research new approaches
  - Forward-training architectures
